## 0.0.30

This new version includes an improved error handling mechanism, expanded test coverage, and a minor version bump.

### New Features

- Expanded test coverage with the addition of ghostwriting tests (cdb0fe) (Eric Ma)

### Bug Fixes

- Improved error handling by changing from raising an error to raising a warning (30cc86) (Eric Ma)

### Deprecations

- No deprecations in this release.

### Other

- Version bumped from 0.0.29 to 0.0.30 (73c1f0) (Eric Ma)
